Only seed database for Debian install if we're using default config
[onak.git] / keydb.h
diff --git a/keydb.h b/keydb.h
index cbdf63dbe1fb82946e507a03847d6fed227dce32..b3be902ff3fb4bd37b1d15f84dea03f725b5a4ac 100644 (file)
--- a/keydb.h
+++ b/keydb.h
@@ -3,28 +3,30 @@
  *
  * Jonathan McDowell <noodles@earth.li>
  *
- * Copyright 2002 Project Purple
- *
- * $Id: keydb.h,v 1.7 2003/06/04 20:57:08 noodles Exp $
+ * Copyright 2002-2004 Project Purple
  */
 
 #ifndef __KEYDB_H__
 #define __KEYDB_H__
 
-// #include <stdint.h>
 #include <inttypes.h>
 
 #include "keystructs.h"
 #include "ll.h"
 
+/**
+ *     struct dbfuncs - All of the functions a DB backend exports.
+ */
+struct dbfuncs {
 /**
  *     initdb - Initialize the key database.
+ *     @readonly: If we'll only be reading the DB, not writing to it.
  *
  *     This function should be called before any of the other functions in
  *     this file are called in order to allow the DB to be initialized ready
  *     for access.
  */
-void initdb(void);
+       void (*initdb)(bool readonly);
 
 /**
  *     cleanupdb - De-initialize the key database.
@@ -32,7 +34,7 @@ void initdb(void);
  *     This function should be called upon program exit to allow the DB to
  *     cleanup after itself.
  */
-void cleanupdb(void);
+       void (*cleanupdb)(void);
 
 /**
  *     starttrans - Start a transaction.
@@ -41,14 +43,14 @@ void cleanupdb(void);
  *     operations on the database to help speed it all up, or if we want
  *     something to only succeed if all relevant operations are successful.
  */
-bool starttrans(void);
+       bool (*starttrans)(void);
 
 /**
  *     endtrans - End a transaction.
  *
  *     Ends a transaction.
  */
-void endtrans(void);
+       void (*endtrans)(void);
 
 /**
  *     fetch_key - Given a keyid fetch the key from storage.
@@ -61,7 +63,8 @@ void endtrans(void);
  *
  *      TODO: What about keyid collisions? Should we use fingerprint instead?
  */
-int fetch_key(uint64_t keyid, struct openpgp_publickey **publickey, bool intrans);
+       int (*fetch_key)(uint64_t keyid, struct openpgp_publickey **publickey,
+                       bool intrans);
 
 /**
  *     store_key - Takes a key and stores it.
@@ -77,7 +80,8 @@ int fetch_key(uint64_t keyid, struct openpgp_publickey **publickey, bool intrans
  *     TODO: Do we store multiple keys of the same id? Or only one and replace
  *     it?
  */
-int store_key(struct openpgp_publickey *publickey, bool intrans, bool update);
+       int (*store_key)(struct openpgp_publickey *publickey, bool intrans,
+                       bool update);
 
 /**
  *     delete_key - Given a keyid delete the key from storage.
@@ -87,7 +91,7 @@ int store_key(struct openpgp_publickey *publickey, bool intrans, bool update);
  *     This function deletes a public key from whatever storage mechanism we
  *     are using. Returns 0 if the key existed.
  */
-int delete_key(uint64_t keyid, bool intrans);
+       int (*delete_key)(uint64_t keyid, bool intrans);
 
 /**
  *     fetch_key_text - Trys to find the keys that contain the supplied text.
@@ -97,7 +101,24 @@ int delete_key(uint64_t keyid, bool intrans);
  *     This function searches for the supplied text and returns the keys that
  *     contain it.
  */
-int fetch_key_text(const char *search, struct openpgp_publickey **publickey);
+       int (*fetch_key_text)(const char *search,
+                       struct openpgp_publickey **publickey);
+
+/**
+ *     update_keys - Takes a list of public keys and updates them in the DB.
+ *     @keys: The keys to update in the DB.
+ *     @sendsync: If we should send a keysync mail.
+ *
+ *     Takes a list of keys and adds them to the database, merging them with
+ *     the key in the database if it's already present there. The key list is
+ *     update to contain the minimum set of updates required to get from what
+ *     we had before to what we have now (ie the set of data that was added to
+ *     the DB). Returns the number of entirely new keys added.
+ *
+ *     If sendsync is true then we send out a keysync mail to our sync peers
+ *     with the update.
+ */
+       int (*update_keys)(struct openpgp_publickey **keys, bool sendsync);
 
 /**
  *     keyid2uid - Takes a keyid and returns the primary UID for it.
@@ -106,16 +127,18 @@ int fetch_key_text(const char *search, struct openpgp_publickey **publickey);
  *     This function returns a UID for the given key. Returns NULL if the key
  *     isn't found.
  */
-char *keyid2uid(uint64_t keyid);
+       char * (*keyid2uid)(uint64_t keyid);
 
 /**
  *     getkeysigs - Gets a linked list of the signatures on a key.
  *     @keyid: The keyid to get the sigs for.
+ *     @revoked: Is the key revoked?
  *
  *     This function gets the list of signatures on a key. Used for key 
*     indexing and doing stats bits.
  */
-struct ll *getkeysigs(uint64_t keyid);
+       struct ll * (*getkeysigs)(uint64_t keyid, bool *revoked);
 
 /**
  *     cached_getkeysigs - Gets the signatures on a key.
@@ -124,7 +147,7 @@ struct ll *getkeysigs(uint64_t keyid);
  *     This function gets the signatures on a key. It's the same as the
  *     getkeysigs function above except we use the hash module to cache the
  */
-struct ll *cached_getkeysigs(uint64_t keyid);
+       struct ll * (*cached_getkeysigs)(uint64_t keyid);
 
 /**
  *     getfullkeyid - Maps a 32bit key id to a 64bit one.
@@ -133,18 +156,21 @@ struct ll *cached_getkeysigs(uint64_t keyid);
  *     This function maps a 32bit key id to the full 64bit one. It returns the
  *     full keyid. If the key isn't found a keyid of 0 is returned.
  */
-uint64_t getfullkeyid(uint64_t keyid);
+       uint64_t (*getfullkeyid)(uint64_t keyid);
 
 /**
- *     dumpdb - dump the key database
- *     @filenamebase: The base filename to use for the dump.
+ *     iterate_keys - call a function once for each key in the db.
+ *     @iterfunc: The function to call.
+ *     @ctx: A context pointer
+ *
+ *     Calls iterfunc once for each key in the database. ctx is passed
+ *     unaltered to iterfunc. This function is intended to aid database dumps
+ *     and statistic calculations.
  *
- *     Dumps the database into one or more files, which contain pure OpenPGP
- *     that can be reimported into onak or gpg. filenamebase provides a base
- *     file name for the dump; several files may be created, all of which will
- *     begin with this string and then have a unique number and a .pgp
- *     extension.
+ *     Returns the number of keys we iterated over.
  */
-int dumpdb(char *filenamebase);
+       int (*iterate_keys)(void (*iterfunc)(void *ctx,
+                       struct openpgp_publickey *key), void *ctx);
+};
 
 #endif /* __KEYDB_H__ */
@@ -106,16 +127,18 @@ int fetch_key_text(const char *search, struct openpgp_publickey **publickey);
  *
  *     This function gets the list of signatures on a key. Used for key 
- *     indexing and doing stats bits.
+ *     indexing and doing stats bits. If revoked is non-NULL then if the key
+ *     is revoked it's set to true.
  */